@@ -7,7 +7,7 @@ use base 'Catalyst::View';
 use Imager;
 use Image::Info qw/image_info/;
 
-our $VERSION = 0.0003;
+our $VERSION = 0.0006;
 
 sub process {
     my ($self, $c) = @_;
@@ -23,44 +23,42 @@ sub process {
     my $image_info = image_info $c->stash->{image};
     my $mime_type = $image_info->{file_media_type};
 
-    # derive `imager acceptable' type from mime (e.g. `png' or `jpeg')
+    # get type that imager can accept like 'png'
     my $imager_type = $mime_type;
     $imager_type =~ s|^image/||;
 
     # default to a stashed type value
-    $imager_type = $c->stash->{image_type} || $imager_type;;
+    $imager_type = $c->stash->{image_type} || $imager_type;
+    
+    # quality of output
+    my $quality = $c->stash->{jpeg_quality} || 100;
 
     # generate thumbnail, returns imager object or an error string
     my $image = $self->generate_thumbnail($c, $imager_type);
-    
-    # return image in response
-    if ( ref $image ) {
 
+    if ( ref $image ) {
         # stash the imager object
         delete $c->stash->{image};
-        $c->stash( image => $image );
+        $c->stash->{image} = $image;
 
         # write image data to a scalar
         my $thumbnail;
         $image->write(
             data => \$thumbnail,
             type => $imager_type,
+            jpegquality => $quality
         );
         
         # stash raw image data
-        $c->stash( image_data => \$thumbnail );
+        $c->stash->{image_data} = \$thumbnail;
         
         # return image in response
         $c->response->content_type($mime_type);
         $c->response->body($thumbnail);
-
-    } 
-
-    else {
+    } else {
         # error out
         $c->error("Couldn't render image: $image");
         return 0;
-
     }
 
 }
@@ -79,20 +77,32 @@ sub generate_thumbnail {
         $c->config->{'View::Thumbnail::Simple'}->{max_image_size} || 15_728_640;
 
     # read image
-    my $image = Imager->new();
+    my $image = Imager->new;
     $image->read( data => ${$c->stash->{image}}, 
                   type => $type, bytes => $max_size )
         or return 'Imager failed to read image: ' . $image->errstr;
-  
-    if ( $c->stash->{image_size} ) {
+    
+    my $size = $c->stash->{image_size};
+
+    my $height = $image->getheight;
+    my $width = $image->getwidth;
+
+    # get longest side to see if it needs to be scaled down
+    my $longest = $height > $width ? $height : $width;
+    
+    if ( $size && ( $size < $longest ) ) {
+        
+        # image needs to be scaled
         
         # amazing algorithm to find the longest side of the image and
         # pass the right parameter to Imager->scale
-        my $dimension = $image->getwidth > $image->getheight ? 
+        my $dimension = $width > $height ? 
             'xpixels' : 'ypixels';
 
-        my $new_image = $image->scale( $dimension => $c->stash->{image_size},
-                                       qtype => 'mixing' );
+        # scaling algo to use
+        my $qtype = $c->config->{'View::Thumbnail::Simple'}->{scaling_qtype} || 'mixing';
+        my $new_image = $image->scale( $dimension => $size,
+                                       qtype => $qtype );
         
         # return scaled image
         return $new_image;
@@ -104,7 +114,11 @@ sub generate_thumbnail {
 
 }
 
+1;
 
+__END__
+
+=pod
 
 =head1 NAME
 
@@ -127,10 +141,10 @@ thumbnailing images
 
 =head1 DESCRIPTION
 
-Another thumbnailer? Yes, but this one uses Imager and is arguably
-much simpler than the other ones out there (note the `Simple' in the
-package name). If you need complex thumbnailing like explicit X & Y
-values and cropping/zooming, please see L<Catalyst::View::Thumbnail>.
+Another thumbnailer? Yes, but this one uses Imager and is simpler than
+the other thumbnailers out there (note the `Simple' in the package
+name). If you need complex thumbnailing like explicit X & Y values and
+cropping/zooming, please see L<Catalyst::View::Thumbnail>.
 
 This module is a View class for Catalyst that will simply and
 efficiently create thumbnails or `scaled' versions of images using
@@ -160,8 +174,8 @@ be scaled accordingly, maintaining it's original aspect ratio.
 
 You can set this attribute to a string (e.g. `png') to try to force
 Imager to read or write an image of a certain file format (note that
-this may fail). Otherwise the image type is derived from the source
-image.
+this may fail). Otherwise the image type is automatically derived from
+the source image.
 
 =item max_image_size
 
@@ -175,6 +189,25 @@ your application's configuration like so:
 
 =back
 
+=head2 Optional config parameters
+
+=over 
+
+=item max_image_size
+
+See above section about max_image_size
+
+=item scaling_qtype
+
+Pick what Imager scaling algo to use, defaults to 'mixing'. Please see
+the documentation on 'scale()' in L<Imager::Transformations>.
+
+=item jpeg_quality
+
+An integer between 0-100 used to determine the quality of the image when writing JPEG files, defaults to 100. Please see the JPEG section of L<Imager::Files>.
+
+=back
+
 =head2 `Returned' stash attributes
 
 After generating the thumbnail from the image data, the following
